# -*- coding: utf-8 -*-
"""
    This Python module is part of the mataraclari package, which provides
    some mathematical shortcuts for Python.

    
    Copyright (C) 2011  Yaşar Arabacı

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
import unittest
from __init__ import *
from random import randint

class carpanlarTests(unittest.TestCase):

    def testCarpanlarSanity(self):

        # 100 rasgele sayi dene
        for i in range(100):
            sayi = randint(0,1000000)
            carp = carpanlar(sayi)

            for carpan in carp:
                self.assertEqual(sayi % carpan,0)

    def testAsalCarpanlarSanity(self):
        # 100 sayi dene
        for i in range(100):
            sayi = randint(0,1000000)
            carpanlar = asalCarpanlar(sayi)
            sonuc = reduce(int.__mul__,carpanlar)
            self.assertEqual(sayi, sonuc)


class asallarToplamiTests(unittest.TestCase):
    asallar = primes(1000)

    def testAsallarToplamiSanity(self):
        for i in range(100):
            girdi = 2 * randint(2,500)
            asal1, asal2 = asallarToplami(girdi)
            self.assertEqual(asal1 + asal2, girdi)
            self.assertTrue(asal1 in self.asallar)
            self.assertTrue(asal2 in self.asallar)

    def testAsallarToplamiHepsiSanity(self):

        for i in range(100):
            girdi = 2  * randint(2,500)
            for asal1, asal2 in asallarToplamiHepsi(girdi):
                self.assertEqual(asal1 + asal2, girdi)
                self.assertTrue(asal1 in self.asallar)
                self.assertTrue(asal2 in self.asallar)
if __name__ == "__main__":
    unittest.main()

        



# -*- coding: utf-8 -*-
"""
    This Python module is part of the mataraclari package, which provides
    some mathematical shortcuts for Python.

    
    Copyright (C) 2011  Yaşar Arabacı

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
from _mathGerecleri import *
from _carpanlar import *

def sadelestir(*args):
    k = obeb(*args)
    return [i/k for i in args]

def EsitlemeKatsayilar(*args):
    k = okek(*args)
    return [k/i for i in args]

def asalMi(sayi):

    eleyenler = primes(int(sayi ** 0.5))

    for asal in eleyenler:
        if sayi % asal == 0:
            return False

    return True

def asallarToplami(sayi):
    """
    Verilen çift sayiyi iki asalin toplami şeklinde
    yazar. Eğer birden fazla asal toplam döndürülebiliyorsa,
    yine de tek bir tane döndürür.
    >>> asallarToplami(8)
    (5,3)
    >>> asallarToplami(10)
    (7,3)
    """

    if sayi % 2 != 0:
        raise ValueError(u"Çift sayı girmelisiniz.")

    asallar = primes(sayi)

    for i in asallar:
        if sayi - i in asallar:
            return (sayi - i, i)

def asallarToplamiHepsi(sayi):

    if sayi % 2 != 0:
        raise ValueError("Çift sayı giriniz.")

    asallar = primes(sayi)
    toplamlar = []

    yarisi = len(asallar) / 2

    for i in range(yarisi + 1):
        asal = asallar[i]
        if sayi - asal in asallar:
            toplamlar.append((sayi-asal, asal))

    return toplamlar



# -*- coding: utf-8 -*-
"""
    This Python module is part of the mataraclari package, which provides
    some mathematical shortcuts for Python.

    
    Copyright (C) 2011  Yaşar Arabacı

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
from itertools import combinations as _combinations
from _mathGerecleri import primes as _primes

def TekilAsalCarpanlar(sayi):
    return sorted(set(asalCarpanlar(sayi)))

def asalCarpanlar(sayi):
    muhtemel_asal_carpanlar = _primes(int(sayi ** 0.5) + 1)

    # Bir tane daha asal çarpan olabilir.
    
    current = sayi
    asal_carpanlar = []
    for i in muhtemel_asal_carpanlar:

        if current == 1:

            break

        while True:

            if current % i == 0:
                asal_carpanlar.append(i)
                current = current / i
            else:
                break

    if current != 1:
        # Son bir asal atlandı...
        asal_carpanlar.append(current)
    return asal_carpanlar
    
def carpanlar(sayi):
    asal_carpanlar = asalCarpanlar(sayi)
    if len(asal_carpanlar) == 1:
        return [1] + [sayi]
    
    sonuc = [1]
    for i in range(1,len(asal_carpanlar)):
        
        for carpilcaklar in _combinations(asal_carpanlar, i):
            
            carpim = carpilcaklar[0]
            for j in range(1,i):
                carpim *= carpilcaklar[j]
            sonuc.append(carpim)

    sonuc.append(sayi)
    return sorted(tuple(set(sonuc)))
            

            
            
            



# -*- coding: utf-8 -*-
from distutils.core import setup, Extension
import os

pack_dir = os.path.join(os.path.dirname(__file__),"mataraclari")

mathgerecleri = Extension('mataraclari._mathGerecleri',
                    sources = ['mataraclari/mathgerecler.c'])

long_description = """ This package provides couple of functions
for solving some mathematical problems, like finding primes. They are
intended to be very fast, and they are as fast as they can be. Hopefully,
this will spare you from reinventing the whell when you need to do some
basic mathematical calculations. Currently readme file is in Turkish, and
yet no other documentation is available, but this may change in future."""

setup(
    name="mataraclari",
    version = '0.13',
    description = 'Provides some math utilities',
    author = 'Yaşar Arabacı',
    author_email = 'yasar11732@gmail.com',
    long_description = long_description,
    license = "GPL v3",
    url = 'http://yasar.serveblog.net',
    packages = ["mataraclari"],
    package_dir = {"mataraclari":pack_dir},
    ext_modules = [mathgerecleri],
    classifiers = [
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Operating System :: OS Independent',
        'Development Status :: 3 - Alpha',
        'Topic :: Scientific/Engineering :: Mathematics',
        ]
    )
